"use client";

import CountDown from "@/components/common/count-down";
import { Button } from "@/components/ui/button";
import { Form, FormControl, FormField, FormItem, FormMessage } from "@/components/ui/form";
import { InputOTP, InputOTPGroup, InputOTPSeparator, InputOTPSlot } from "@/components/ui/input-otp";
import { useRouter } from "@/i18n/routing";
import { zodResolver } from "@hookform/resolvers/zod";
import { Icon } from "@iconify/react/dist/iconify.js";
import Cookies from "js-cookie";
import { useTranslations } from "next-intl";
import { useState, useTransition } from "react";
import { useForm } from "react-hook-form";
import { toast } from "sonner";
import { z } from "zod";
import { submitLogin, verifyCode } from "./actions";


export default function VerifyForm() {
	const t = useTranslations("VerifyPage");

	const [isPending, startTransition] = useTransition();
	const [isResending, startResending] = useTransition();

	const router = useRouter();
	const [timeLeft, setTimeLeft] = useState(180);
	const [isTimerRunning, setIsTimerRunning] = useState(true);


	const formSchema = z.object({
		code: z
			.string()
			.min(4, t("validation.code.required"))
			.max(4, t("validation.code.invalid")),
	});

	const form = useForm<{ code: string }>({
		resolver: zodResolver(formSchema),
		defaultValues: {
			code: "",
		},
	});


	async function onSubmit({ code }: any) {
		startTransition(async () => {
			try {
				const result = await verifyCode({
					code: code,
					phone: `966${Cookies.get("__p")}`
				});
				console.log("result: ", result);

				if (result.success) {
					toast.success(t("Request submitted successfully"), {
						style: {
							backgroundColor: "green",
							color: "white",
						},
					});
					setIsTimerRunning(false);
					Cookies.set("__t", result?.data?.access_token, { expires: 1 });
					router.push("/");
					Cookies.remove("__p");

				} else {
					if (result?.message) toast.error(t(result.message));
					if (result?.errors) {
						Object?.entries(result.errors).forEach(([key, errors]) => {
							if (Array.isArray(errors)) {
								errors?.forEach(error => toast.error(t(error.replace(".", ""))));
							}
						});
					}
					if (result?.message == "The verification code has expired") setTimeLeft(0);
				}
			} catch (error: any) {
				toast.error(t("Something went wrong"));
			}
		});
	}

	async function handleResendCode() {
		startResending(async () => {
			try {
				const _phone = `966${Cookies.get("__p")}`;
				const result = await submitLogin({ phone: _phone });
				console.log("result: ", result);

				if (result.success) {
					toast.success(t("ResendCodeSuccess"), {
						style: {
							backgroundColor: "green",
							color: "white",
						},
					});

					setTimeLeft(180); // Reset timer to 3 minutes

				} else {
					toast.error(t(result.message));
				}
			} catch (error: any) {
				toast.error(t("Something went wrong"));
			}
		});
	}

	console.log("isResending: ", isResending);

	console.log("timeLeft: ", timeLeft);

	console.log(timeLeft > 0);
	return (

		<Form {...form}>
			<div className="w-full">
				<form
					onSubmit={form.handleSubmit(onSubmit)}
					className="w-full space-y-12"
				>
					<CountDown timeLeft={timeLeft} setTimeLeft={setTimeLeft} isTimerRunning={isTimerRunning} />
					<div dir="ltr" className="grid grid-cols-1 gap-4">
						<div className="flex items-center justify-center">
							<FormField
								control={form.control}
								name="code"
								render={({ field }) => (
									<FormItem>
										<FormControl>
											<InputOTP maxLength={4} {...field}>
												<InputOTPGroup>
													<InputOTPSlot index={0} />
													<InputOTPSlot index={1} />
												</InputOTPGroup>
												<InputOTPSeparator />
												<InputOTPGroup>
													<InputOTPSlot index={2} />
													<InputOTPSlot index={3} />
												</InputOTPGroup>
											</InputOTP>
										</FormControl>
										<FormMessage className="text-center" />
									</FormItem>
								)}
							/>
						</div>
					</div>

					<div className="flex flex-col items-center justify-between">
						<Button
							type="submit"
							disabled={isPending}
							className="flex w-full items-center justify-center gap-2 bg-[#606676] hover:bg-gray-700"
							style={{ boxShadow: "10px 25px 61px -1px #1D1D1D40" }}
						>
							{isPending ? (
								<div className="flex items-center justify-center gap-2">
									{t("Loading")}
									<Icon
										icon="eos-icons:bubble-loading"
										width="24"
										height="24"
										style={{ color: "#B9B9B9" }}
									/>
								</div>
							) : (
								t("verifyButton")
							)}
						</Button>
					</div>
				</form>
				<div className="my-4 flex justify-center gap-1">
					<Button variant="link" className="text-white"
						disabled={timeLeft > 0}
						onClick={handleResendCode}>
						{
							isResending ?
								<div className="flex items-center justify-center gap-2">
									{t("Resending")}
									<Icon
										icon="eos-icons:bubble-loading"
										width="24"
										style={{ color: "#B9B9B9" }}
									/>
								</div>

								: t("ResendCode")
						}
					</Button>
				</div>
			</div>
		</Form>
	);
}


